#!/usr/bin/env perl

# Run from e.g. release3/cere/strains. Arguments "a" for fasta or "q" for fastq, then fate(s) for which we want reads
# extracted, e.g. q never_aligned.
# Outputs fasta or fastq data to standard output.

use Utility;
use strict;

my $aq = shift @ARGV;
my $FASTA;
if ($aq eq 'a') {
    $FASTA = 1;
} elsif ($aq ne 'q') {
    die("Usage: $0 [a|q] fate1 fate2 ...\n");
}    

my %WANTED = map {$_ => 1} @ARGV;

foreach my $d (glob("*")) {
    extractReadsWithFates($d);
}

sub extractReadsWithFates {
    my ($d) = @_;
    my $fastq = "$d/renamed.fastq";
    my $fates = "$d/fates.txt";
    return unless (-s $fates && -s $fastq);
    my $fh = openToRead($fates);
    my %wantRead;
    while (<$fh>) {
	chomp;
	my ($read,@rest) = split;
	$wantRead{$read} = 1 if ($WANTED{$rest[-1]});
    }
    $fh = openToRead($fastq);
    while (1) {
	my @quad;
	foreach my $i (0 .. 3) {
	    my $line = <$fh>;
	    push @quad,$line;
	}
	last unless ($quad[0]);
	my ($read) = split(" ",substr($quad[0],1));
	if ($wantRead{$read}) {
	    if ($FASTA) {
		print ">$read\n$quad[1]";
	    } else {
		print @quad;
	    }
	}
    }
}
